// x-bearing-end is the right end of the X axis, it holds the bearing for the pulley, is attached to the Z shaft with 
// linear ball bearings, and is moved by the Z leadscrew
// It also holds the two X shafts
// It is derived from the base x-end ( x_end_base )

include <../config.scad>;
include <base-components/x-end-base.scad>;

// Component-specific calculated values
bearing_holder_distance = z_linear_bearing_outside_diameter + 2*2 + 10; 

translate ([8,-30,-27]) rotate(a=[0,270,0]){ x_adapter_end(); }

module x_bearing_end(){
    difference(){
        union(){
            // Base x-end solid : as both are a mirror, we only code it once
            x_end_base(); 
        }

        // Remove extraneous solid
        translate([52,-junction_assurance_length,-junction_assurance_length]){
            cube([200,200,200]);
        }


        // Holes for 5mm bearing holder bolt
        translate([bearing_holder_distance, 0, x_end_box_height/2]){ 
            rotate(a=[90,0,0]){
                cylinder(h=200, r=(5/2)+holes_extra_radius_compensation, center=true, $fn=10);
            }
        }
    }

}

// MODULE DE TRAVAIL CI-DESSOUS

module x_adapter_end(){
// bottom part



difference() {
difference() {
difference() {
difference() {
translate([z_linear_bearing_outside_diameter + 9 - junction_assurance_length,31 - junction_assurance_length,8])x_fixe_cube();
translate([z_linear_bearing_outside_diameter + 7 - junction_assurance_length,38 - junction_assurance_length,12])cube([10,20,52]);
}
translate([z_linear_bearing_outside_diameter + 11 - junction_assurance_length,0 - junction_assurance_length,31])cube([8,100,8]);
}
translate([z_linear_bearing_outside_diameter + 25 - junction_assurance_length,48 - junction_assurance_length,12])cube([10,10,52]);
}
translate([z_linear_bearing_outside_diameter + 25 - junction_assurance_length,26 - junction_assurance_length,12])cube([10,10,52]);
}


}


module x_fixe_cube(){
	difference(){
         
                // Base holder
                // Base holder
                cube([24 + junction_assurance_length, 
                     ( z_linear_bearing_outside_diameter + 3 ) + junction_assurance_length , 
                     x_end_leadscrew_nut_holder_height +54]);

                // Holes
                // Aligned with the linear ball bearing in X, and distant from it by z_shaft_to_leadscrew_distance
                translate([z_shaft_to_leadscrew_distance - (z_linear_bearing_outside_diameter + 14)/2,
                          (z_linear_bearing_outside_diameter + 2)/2,
                          -junction_assurance_length]){   
                    
                    // Main ( leadscrew ) hole
                    cylinder(h = 200, r = ((z_leadscrew_diameter+2)/2)+holes_extra_radius_compensation, center = true, $fn=20); 

                    // Holes for fixation screws for leadscrew nut ( 4 holes, larger nut size )

                    if( z_nut_type == 2 ){
                        for(rotation = [0:2]){
                            // Rotation of the hole around the center hole
                            rotate(a=[0,0,(120*rotation)+180]){
                                translate([11,0,0]){
                                    // Rotation of the hole around itself 
                                    rotate(a=[0,0,(60*rotation)+180]){
                                        translate([1.5,0,0]){
                                            cylinder(h=200, r=(z_leadscrew_nut_screw_diameter/2)+holes_extra_radius_compensation, center = true, $fn=20);
                                        }
                                        translate([-1.5,0,0]){
                                            cylinder(h=200, r=(z_leadscrew_nut_screw_diameter/2)+holes_extra_radius_compensation, center = true, $fn=20);
                                        }
                                        translate([-1.5,0-(  ((z_leadscrew_nut_screw_diameter+2)/2)+holes_extra_radius_compensation  )/2,0]){ cube([3, ((z_leadscrew_nut_screw_diameter+2)/2)+holes_extra_radius_compensation, 200]); }
                                    } 
                                }
                            }
                        }
                    }


                }
            }
	}
